use std::fmt::{Display, Formatter};

#[derive(Clone, Debug)]
pub enum SocketControlEvent {
	Create(String),
	Disconnect,
}

#[derive(Hash, Ord, PartialOrd, Eq, PartialEq, Copy, Clone, Debug, Default)]
pub enum SocketState {
	#[default]
	Pending,
	Connected,
	Disconnected,
	Closed,
}

impl Display for SocketState {
	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
		write!(f, "{:?}", self)
	}
}

pub trait FromSocketMessage {
	fn from_text(value: String) -> Self;
	fn from_binary(value: Vec<u8>) -> Self;
}
pub trait ToSocketMessage {
	fn to_text(&self) -> String;
}

#[cfg(not(target_arch = "wasm32"))]
pub use crate::desktop::RemoteEventError;
#[cfg(target_arch = "wasm32")]
pub use crate::wasm::RemoteEventError;

pub type RemoteEventResult<T> = Result<T, RemoteEventError>;
