use std::fmt::{Debug, Display, Formatter};

#[cfg(not(target_arch = "wasm32"))]
mod desktop;
pub mod events;
#[cfg(target_arch = "wasm32")]
mod wasm;

#[cfg(not(target_arch = "wasm32"))]
pub use self::desktop::RemoteEventDispatcher;
#[cfg(not(target_arch = "wasm32"))]
pub use self::desktop::RemoteEventPlugin;
#[cfg(target_arch = "wasm32")]
pub use self::wasm::RemoteEventDispatcher;
#[cfg(target_arch = "wasm32")]
pub use self::wasm::RemoteEventPlugin;

impl<SentMessageType, ReceivedMessageType> Debug
	for RemoteEventDispatcher<SentMessageType, ReceivedMessageType>
where
	ReceivedMessageType: crate::events::FromSocketMessage + Send + Sync + 'static,
	SentMessageType: crate::events::ToSocketMessage + Send + Sync + 'static,
{
	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
		f.debug_struct("RemoteEventDispatcher")
			.field("status", &self.status)
			.finish()
	}
}

impl<SentMessageType, ReceivedMessageType> Display
	for RemoteEventDispatcher<SentMessageType, ReceivedMessageType>
where
	ReceivedMessageType: crate::events::FromSocketMessage + Send + Sync + 'static,
	SentMessageType: crate::events::ToSocketMessage + Send + Sync + 'static,
{
	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
		f.debug_tuple("RemoteEventDispatcher")
			.field(&self.status)
			.finish()
	}
}
